@@ -26,10 +26,10 @@ class Folder(object):
                     self.client.getAPIStatus(xml_response),
                     self.client.getAPIMessages(xml_response))
 
-    def all(self):
+    def all(self,page_no):
         xml_string = get_xml_as_string('list.xml')
         xml_string = xml_string.format(sid=self.client._session_id,
-                                       method_name='folder.list')
+                   page=page_no,method_name='folder.list')
 
         xml_response = self.client.doHttpCall(data=xml_string)
 
